# python-pensionpro

This is a library for the PensionPro TPA management software for python 3.6+.

It includes the following features from the PensionPro V1 API

* Contacts
    - Get by Id
* Plans
    - Get by Id
* Plan Contact Roles
    - Get by Id
    - List with filter